@@ -15,7 +15,6 @@ import           Devel                  (DevelOpts (..), devel, DevelTermOpt(..)
 import           Keter                  (keter)
 import           Options                (injectDefaults)
 import qualified Paths_yesod_bin
-import           Scaffolding.Scaffolder (scaffold, backendOptions)
 
 import           HsFile                 (mkHsFile)
 #ifndef WINDOWS
@@ -43,7 +42,7 @@ data Options = Options
                }
   deriving (Show, Eq)
 
-data Command = Init { _initBare :: Bool, _initName :: Maybe String, _initDatabase :: Maybe String }
+data Command = Init [String]
              | HsFiles
              | Configure
              | Build { buildExtraArgs   :: [String] }
@@ -102,7 +101,7 @@ main = do
          ] optParser'
   let cabal = rawSystem' (cabalCommand o)
   case optCommand o of
-    Init{..}        -> scaffold _initBare _initName _initDatabase
+    Init _          -> error "The init command has been removed. Please use 'stack new' instead"
     HsFiles         -> mkHsFile
     Configure       -> cabal ["configure"]
     Build es        -> touch' >> cabal ("build":es)
@@ -156,7 +155,7 @@ optParser = Options
         <$> flag Cabal CabalDev ( long "dev"     <> short 'd' <> help "use cabal-dev" )
         <*> switch              ( long "verbose" <> short 'v' <> help "More verbose output" )
         <*> subparser ( command "init"         (info initOptions
-                            (progDesc "Scaffold a new site"))
+                            (progDesc "Command no longer available, please use 'stack new'"))
                       <> command "hsfiles" (info (pure HsFiles)
                             (progDesc "Create a hsfiles file for the current folder"))
                       <> command "configure" (info (pure Configure)
@@ -179,12 +178,7 @@ optParser = Options
                       )
 
 initOptions :: Parser Command
-initOptions = Init
-    <$> switch (long "bare" <> help "Create files in current folder")
-    <*> optStr (long "name" <> short 'n' <> metavar "APP_NAME"
-            <> help "Set the application name")
-    <*> optStr (long "database" <> short 'd' <> metavar "DATABASE"
-            <> help ("Preconfigure for selected database (options: " ++ backendOptions ++ ")"))
+initOptions = Init <$> many (argument str mempty)
 
 keterOptions :: Parser Command
 keterOptions = Keter
